@@ -11,14 +11,14 @@ def get_grammar():
     return open(pth, "r").read()
 
 
-def stix2sql(pattern, sco_type):
+def stix2sql(pattern, sco_type, dialect='sqlite3'):
     grammar = get_grammar()
     return Lark(grammar,
                 parser="lalr",
-                transformer=_TranslateTree(sco_type)).parse(pattern)
+                transformer=_TranslateTree(sco_type, dialect)).parse(pattern)
 
 
-def _convert_op(sco_type, prop, op, rhs):
+def _convert_op(sco_type, prop, op, rhs, dialect):
     orig_op = op
     neg, _, op = op.rpartition(' ')
     if op == 'ISSUBSET':
@@ -43,7 +43,6 @@ def _convert_op(sco_type, prop, op, rhs):
         elif op == 'LIKE':
             return f'{neg} like_bin(CAST({rhs} AS TEXT), "{prop}")'
     elif op == 'MATCHES':
-        rhs = rhs.replace('\\\\', '\\')
         return f'{neg} match({rhs}, "{prop}")'
     prop, chunk, subprop = prop.partition('[*]')
     if chunk:
@@ -56,16 +55,18 @@ def _convert_op(sco_type, prop, op, rhs):
             rhs = f"'%\"{subprop}\":\"{rhs}\"%'"
         else:
             rhs = f"'%{rhs}%'"
+    if dialect == 'postgresql' and op == 'LIKE':
+        rhs = rhs.replace("\\", r"\\")  # PostgreSQL uses \ for escape with LIKE only!
     return f'"{prop}" {neg} {op} {rhs}'
 
 
-def comp2sql(sco_type, prop, op, value):
+def comp2sql(sco_type, prop, op, value, dialect):
     result = ''
     links = parse_prop(sco_type, prop)
     for link in reversed(links):
         if link[0] == 'node':
             from_type = link[1] or sco_type
-            result = _convert_op(from_type, link[2], op, value)
+            result = _convert_op(from_type, link[2], op, value, dialect)
         elif link[0] == 'rel':
             _, from_type, ref_name, to_type = link
             if ref_name.endswith('_refs'):
@@ -94,8 +95,9 @@ def path2sql(sco_type, path):
 class _TranslateTree(Transformer):
     """Transformer to convert relevant parts of STIX pattern to WHERE clause"""
 
-    def __init__(self, sco_type):
+    def __init__(self, sco_type, dialect):
         self.sco_type = sco_type
+        self.dialect = dialect
 
     def _make_comp(self, lhs, op, rhs):
         orig_op = op
@@ -103,7 +105,7 @@ class _TranslateTree(Transformer):
 
         # Ignore object paths that don't match table type
         if self.sco_type == sco_type:
-            return comp2sql(sco_type, prop, op, rhs)
+            return comp2sql(sco_type, prop, op, rhs, self.dialect)
         return ''
 
     def _make_exp(self, lhs, op, rhs):
@@ -137,6 +139,9 @@ class _TranslateTree(Transformer):
         return f'{value}'
 
     def quoted_str(self, value):
+        # Adapt the string literal from STIX escapes to SQL escapes
+        value = value.replace(r'\\', '\\')  # Convert double backslash to single
+        value = value.replace(r"\'", "''")  # Convert escape from backslash to apostrophe
         return f"'{value}'"
 
     def lit_list(self, *args):
