@@ -88,7 +88,7 @@ def format_val(sco_type, prop, val):
         except ValueError:
             result = int(val, 16)
     elif prop == 'protocols':  # HACKY
-        result = [val]
+        result = [val] if not isinstance(val, list) else val
     elif prop == 'key':
         result = val
         for abbrev, full in REG_HIVE_MAP.items():
@@ -118,7 +118,8 @@ def set_obs_prop(observable, path, val, scos, key):
         scos[ref_key] = other
         if ref_name in observable:
             refs = observable[ref_name]
-            refs.append(ref_key)
+            if ref_key not in refs:
+                refs.append(ref_key)
         else:
             refs = [None for i in range(int(idx) + 1)]
             refs[int(idx)] = ref_key
@@ -304,6 +305,11 @@ def to_action_code(event_id):
     ]
 
 
+def to_cat_list(category):
+    value = category if isinstance(category, list) else [category]
+    return [('x-oca-event:category', value)]
+
+
 def to_payload_bin(value):
     return [
         ('artifact:payload_bin', base64.b64encode(value.encode()).decode('ascii'))
@@ -326,11 +332,11 @@ def is_file_event(event_id):
     return event_id in {6, 7, 9, 11, 15}
 
 
-def split_hash(hash_string: str):
+def split_hash(hash_string: str, prefix: str, tag: str = ''):
     token_dict = {
-        "SHA1=": "process:binary_ref.hashes.'SHA-1'",
-        "MD5=": "process:binary_ref.hashes.MD5",
-        "SHA256=": "process:binary_ref.hashes.'SHA-256'"
+        "SHA1=": f"{prefix}hashes.'SHA-1'{tag}",
+        "MD5=": f"{prefix}hashes.MD5{tag}",
+        "SHA256=": f"{prefix}hashes.'SHA-256'{tag}"
     }
     hashes = []
     for hstr in hash_string.split(','):
@@ -340,6 +346,18 @@ def split_hash(hash_string: str):
     return hashes
 
 
+def split_image_hash(hash_string: str):
+    return split_hash(hash_string, 'process:binary_ref.')
+
+
+def split_file_hash(hash_string: str):
+    return split_hash(hash_string, 'file:')
+
+
+def split_loaded_hash(hash_string: str):
+    return split_hash(hash_string, 'file:', '#loaded')
+
+
 def split_image(abs_name: str, prefix='process:'):
     name = ntpath.basename(abs_name)
     path = ntpath.dirname(abs_name)
@@ -363,6 +381,15 @@ def split_image_loaded(abs_name: str):
     ]
 
 
+def split_file_path(abs_name: str, prefix='file:'):
+    name = ntpath.basename(abs_name)
+    path = ntpath.dirname(abs_name)
+    return [
+        (prefix + 'name', name),
+        (prefix + 'parent_directory_ref.path', path)
+    ]
+
+
 def split_reg_key_value(path: str):
     key, _, value = path.rpartition('\\')
     return [
@@ -416,7 +443,7 @@ windows_mapping = {
         #"UserID": "process:creator_user_ref.user_id",
         #"User": "process:creator_user_ref.account_login",
         "User": "process:creator_user_ref.user_id",
-        "Hashes": split_hash,
+        "Hashes": split_image_hash,
     },
     3: {
         "UtcTime": ["first_observed", "last_observed"],
@@ -442,7 +469,14 @@ windows_mapping = {
         "ProcessId": "process:pid",
         "ProcessGuid": "process:x_unique_id",
         "CommandLine": ["process:command_line"],
-        "Hashes": split_hash,
+        "Hashes": split_loaded_hash,
+    },
+    11: {
+        "UtcTime": ["first_observed", "last_observed"],
+        "Image": split_image,
+        "ProcessId": "process:pid",
+        "ProcessGuid": "process:x_unique_id",
+        "TargetFilename": split_file_path,
     },
     12: {
         "UtcTime": ["first_observed", "last_observed"],
@@ -568,7 +602,7 @@ class SdsMapper(Mapper):
         "SourceName": "x-oca-event:provider",
         "Hostname": "x-oca-asset:hostname",
         "EventID": to_action_code,
-        "Category": "x-oca-event:category",
+        "Category": to_cat_list,  # "x-oca-event:category" is defined to be a list
         "Message": lambda x: SdsMapper.enhanced_action(x),
         #"Message": to_payload_bin,
         "ProcessName": split_image,  # At least some events use this instead of Image
